************************************
* SLMPS Data Demo
* Caroline Krafft
* v1
* Original : 2023.09.13
* Last updated: 2023.09.13
************************************
*Directory


*Caroline's laptop path
*Update to your directory
cd "/Users/Caroline/Dropbox/SLMPS analysis/"

clear
clear matrix
clear mata
set maxvar 10000
version 16.1

*Use data
use "SLMPS Data/SLMPS v2.1 all.dta", clear


********
*Weights demo
********


*Population by wilaya using weights
*Expansion weights - household weight because household variable
table admin1 [pw=expan_hh], row format(%10.0f)
*Row option shows total, format shows full number, no decimal places

*Analytical weights - household weight because household variable
*Percentage in each wilaya
tabu admin1 [aw=expan_hh]

*Can also use household weights for data from the roster (since that's household data)
*Population structure by age group
tabu agegrp2 [aw=expan_hh]

*Need to use individual weights for data from individual questionnaire (incl. labor market statuses)
*Current labor market status by sex
tabu crwrkstsr1 sex if age>=15 & age<=64 [aw=expan_ind], col nofreq
*NOTE: not an unemployment rate! 

********************************************************************************
*Share unemployed vs. unemployment rate
********************************************************************************
*unemp* variables are as a share of population
*unemp*m as a share of labor force --> unemployment rates
*unempsr* requires search
*without search includes the discouraged unemployed

table sex if age>=15 & age<=64 [aw=expan_ind], c(mean unemp1 mean unempsr1 mean unemp1m mean unempsr1m) row format(%9.3f)

********************************************************************************
*Current standard market labor force participation rate - table by covariates
********************************************************************************

*Proportion in the labor force by sex
table sex if age>=15 & age<=64 [pw=expan_ind], c(mean crlfsr1) row format(%9.3f)

*Proportion in the labor force by sex and urban/rural
table sex urban if age>=15 & age<=64 [pw=expan_ind], c(mean crlfsr1) row col format(%9.3f)

*Proportion in the labor force by sex, education, and urban/rural
table educ1d sex urban if age>=15 & age<=64 [pw=expan_ind], c(mean crlfsr1) row col scol format(%9.3f)

********************************************************************************
*Prevalence vs. distribution: the employed
********************************************************************************

*Prevalence: What percentage of each sex works? (employed in sex/population in sex)
table sex if age>=15 & age<=64  [pw=expan_ind], c(mean cremp1) row format(%9.3f)
*59% of men and 12% of women are employed

*Distribution: What percentage of the employed are male vs. female (employed in sex/all employed)
tabu sex if age>=15 & age<=64 & cremp1==1 [aw=expan_ind]
*Among the employed, 82% are men and 18% are women

